Processor.App.ArticleUtils.article_utils — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.ArticleUtils.article_utils

Functions

`article_content_transform`([fc_eval, ...]) |
`author_transform`(author) |
`brief_transform`(text) |
`category_transform`(category) |
`comments_num_transform`(text) |
`cz_date_transform`(date_str) |
`date_complex_extract`(soup, date_css, ...[, ...]) |
`format_date_transform`(format) |
`headline_transform`(headline) |
`iso_date_transform`(text) |
`keywords_transform`(text) |
`must_exist_filter`(soup, filter_list) |
`must_not_exist_filter`(soup, filter_list) |
`remove_day_transform`(date_str) |
`text_unification_transform`(text) |
`text_unifications_transform`(text) |
`url_category_transform`(url) |